# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.analytics.admin_v1alpha.services.analytics_admin_service.client import (
    AnalyticsAdminServiceClient,
)
from google.analytics.admin_v1alpha.services.analytics_admin_service.async_client import (
    AnalyticsAdminServiceAsyncClient,
)

from google.analytics.admin_v1alpha.types.analytics_admin import (
    ArchiveCustomDimensionRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ArchiveCustomMetricRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import AuditUserLinksRequest
from google.analytics.admin_v1alpha.types.analytics_admin import AuditUserLinksResponse
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchCreateUserLinksRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchCreateUserLinksResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchDeleteUserLinksRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchGetUserLinksRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchGetUserLinksResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchUpdateUserLinksRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    BatchUpdateUserLinksResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateConversionEventRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateCustomDimensionRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateCustomMetricRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateFirebaseLinkRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateGoogleAdsLinkRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateMeasurementProtocolSecretRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import CreatePropertyRequest
from google.analytics.admin_v1alpha.types.analytics_admin import CreateUserLinkRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    CreateWebDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import DeleteAccountRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteAndroidAppDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteConversionEventRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteFirebaseLinkRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteGoogleAdsLinkRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteIosAppDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteMeasurementProtocolSecretRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import DeletePropertyRequest
from google.analytics.admin_v1alpha.types.analytics_admin import DeleteUserLinkRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    DeleteWebDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import GetAccountRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetAndroidAppDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetConversionEventRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetCustomDimensionRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import GetCustomMetricRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetDataSharingSettingsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetEnhancedMeasurementSettingsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import GetGlobalSiteTagRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetGoogleSignalsSettingsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetIosAppDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    GetMeasurementProtocolSecretRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import GetPropertyRequest
from google.analytics.admin_v1alpha.types.analytics_admin import GetUserLinkRequest
from google.analytics.admin_v1alpha.types.analytics_admin import GetWebDataStreamRequest
from google.analytics.admin_v1alpha.types.analytics_admin import ListAccountsRequest
from google.analytics.admin_v1alpha.types.analytics_admin import ListAccountsResponse
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListAccountSummariesRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListAccountSummariesResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListAndroidAppDataStreamsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListAndroidAppDataStreamsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListConversionEventsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListConversionEventsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListCustomDimensionsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListCustomDimensionsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListCustomMetricsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListCustomMetricsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListFirebaseLinksRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListFirebaseLinksResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListGoogleAdsLinksRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListGoogleAdsLinksResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListIosAppDataStreamsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListIosAppDataStreamsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListMeasurementProtocolSecretsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListMeasurementProtocolSecretsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import ListPropertiesRequest
from google.analytics.admin_v1alpha.types.analytics_admin import ListPropertiesResponse
from google.analytics.admin_v1alpha.types.analytics_admin import ListUserLinksRequest
from google.analytics.admin_v1alpha.types.analytics_admin import ListUserLinksResponse
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListWebDataStreamsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ListWebDataStreamsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ProvisionAccountTicketRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    ProvisionAccountTicketResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    SearchChangeHistoryEventsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    SearchChangeHistoryEventsResponse,
)
from google.analytics.admin_v1alpha.types.analytics_admin import UpdateAccountRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateAndroidAppDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateCustomDimensionRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateCustomMetricRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateEnhancedMeasurementSettingsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateFirebaseLinkRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateGoogleAdsLinkRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateGoogleSignalsSettingsRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateIosAppDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateMeasurementProtocolSecretRequest,
)
from google.analytics.admin_v1alpha.types.analytics_admin import UpdatePropertyRequest
from google.analytics.admin_v1alpha.types.analytics_admin import UpdateUserLinkRequest
from google.analytics.admin_v1alpha.types.analytics_admin import (
    UpdateWebDataStreamRequest,
)
from google.analytics.admin_v1alpha.types.resources import Account
from google.analytics.admin_v1alpha.types.resources import AccountSummary
from google.analytics.admin_v1alpha.types.resources import AndroidAppDataStream
from google.analytics.admin_v1alpha.types.resources import AuditUserLink
from google.analytics.admin_v1alpha.types.resources import ChangeHistoryChange
from google.analytics.admin_v1alpha.types.resources import ChangeHistoryEvent
from google.analytics.admin_v1alpha.types.resources import ConversionEvent
from google.analytics.admin_v1alpha.types.resources import CustomDimension
from google.analytics.admin_v1alpha.types.resources import CustomMetric
from google.analytics.admin_v1alpha.types.resources import DataSharingSettings
from google.analytics.admin_v1alpha.types.resources import EnhancedMeasurementSettings
from google.analytics.admin_v1alpha.types.resources import FirebaseLink
from google.analytics.admin_v1alpha.types.resources import GlobalSiteTag
from google.analytics.admin_v1alpha.types.resources import GoogleAdsLink
from google.analytics.admin_v1alpha.types.resources import GoogleSignalsSettings
from google.analytics.admin_v1alpha.types.resources import IosAppDataStream
from google.analytics.admin_v1alpha.types.resources import MeasurementProtocolSecret
from google.analytics.admin_v1alpha.types.resources import Property
from google.analytics.admin_v1alpha.types.resources import PropertySummary
from google.analytics.admin_v1alpha.types.resources import UserLink
from google.analytics.admin_v1alpha.types.resources import WebDataStream
from google.analytics.admin_v1alpha.types.resources import ActionType
from google.analytics.admin_v1alpha.types.resources import ActorType
from google.analytics.admin_v1alpha.types.resources import ChangeHistoryResourceType
from google.analytics.admin_v1alpha.types.resources import GoogleSignalsConsent
from google.analytics.admin_v1alpha.types.resources import GoogleSignalsState
from google.analytics.admin_v1alpha.types.resources import IndustryCategory
from google.analytics.admin_v1alpha.types.resources import MaximumUserAccess

__all__ = (
    "AnalyticsAdminServiceClient",
    "AnalyticsAdminServiceAsyncClient",
    "ArchiveCustomDimensionRequest",
    "ArchiveCustomMetricRequest",
    "AuditUserLinksRequest",
    "AuditUserLinksResponse",
    "BatchCreateUserLinksRequest",
    "BatchCreateUserLinksResponse",
    "BatchDeleteUserLinksRequest",
    "BatchGetUserLinksRequest",
    "BatchGetUserLinksResponse",
    "BatchUpdateUserLinksRequest",
    "BatchUpdateUserLinksResponse",
    "CreateConversionEventRequest",
    "CreateCustomDimensionRequest",
    "CreateCustomMetricRequest",
    "CreateFirebaseLinkRequest",
    "CreateGoogleAdsLinkRequest",
    "CreateMeasurementProtocolSecretRequest",
    "CreatePropertyRequest",
    "CreateUserLinkRequest",
    "CreateWebDataStreamRequest",
    "DeleteAccountRequest",
    "DeleteAndroidAppDataStreamRequest",
    "DeleteConversionEventRequest",
    "DeleteFirebaseLinkRequest",
    "DeleteGoogleAdsLinkRequest",
    "DeleteIosAppDataStreamRequest",
    "DeleteMeasurementProtocolSecretRequest",
    "DeletePropertyRequest",
    "DeleteUserLinkRequest",
    "DeleteWebDataStreamRequest",
    "GetAccountRequest",
    "GetAndroidAppDataStreamRequest",
    "GetConversionEventRequest",
    "GetCustomDimensionRequest",
    "GetCustomMetricRequest",
    "GetDataSharingSettingsRequest",
    "GetEnhancedMeasurementSettingsRequest",
    "GetGlobalSiteTagRequest",
    "GetGoogleSignalsSettingsRequest",
    "GetIosAppDataStreamRequest",
    "GetMeasurementProtocolSecretRequest",
    "GetPropertyRequest",
    "GetUserLinkRequest",
    "GetWebDataStreamRequest",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "ListAccountSummariesRequest",
    "ListAccountSummariesResponse",
    "ListAndroidAppDataStreamsRequest",
    "ListAndroidAppDataStreamsResponse",
    "ListConversionEventsRequest",
    "ListConversionEventsResponse",
    "ListCustomDimensionsRequest",
    "ListCustomDimensionsResponse",
    "ListCustomMetricsRequest",
    "ListCustomMetricsResponse",
    "ListFirebaseLinksRequest",
    "ListFirebaseLinksResponse",
    "ListGoogleAdsLinksRequest",
    "ListGoogleAdsLinksResponse",
    "ListIosAppDataStreamsRequest",
    "ListIosAppDataStreamsResponse",
    "ListMeasurementProtocolSecretsRequest",
    "ListMeasurementProtocolSecretsResponse",
    "ListPropertiesRequest",
    "ListPropertiesResponse",
    "ListUserLinksRequest",
    "ListUserLinksResponse",
    "ListWebDataStreamsRequest",
    "ListWebDataStreamsResponse",
    "ProvisionAccountTicketRequest",
    "ProvisionAccountTicketResponse",
    "SearchChangeHistoryEventsRequest",
    "SearchChangeHistoryEventsResponse",
    "UpdateAccountRequest",
    "UpdateAndroidAppDataStreamRequest",
    "UpdateCustomDimensionRequest",
    "UpdateCustomMetricRequest",
    "UpdateEnhancedMeasurementSettingsRequest",
    "UpdateFirebaseLinkRequest",
    "UpdateGoogleAdsLinkRequest",
    "UpdateGoogleSignalsSettingsRequest",
    "UpdateIosAppDataStreamRequest",
    "UpdateMeasurementProtocolSecretRequest",
    "UpdatePropertyRequest",
    "UpdateUserLinkRequest",
    "UpdateWebDataStreamRequest",
    "Account",
    "AccountSummary",
    "AndroidAppDataStream",
    "AuditUserLink",
    "ChangeHistoryChange",
    "ChangeHistoryEvent",
    "ConversionEvent",
    "CustomDimension",
    "CustomMetric",
    "DataSharingSettings",
    "EnhancedMeasurementSettings",
    "FirebaseLink",
    "GlobalSiteTag",
    "GoogleAdsLink",
    "GoogleSignalsSettings",
    "IosAppDataStream",
    "MeasurementProtocolSecret",
    "Property",
    "PropertySummary",
    "UserLink",
    "WebDataStream",
    "ActionType",
    "ActorType",
    "ChangeHistoryResourceType",
    "GoogleSignalsConsent",
    "GoogleSignalsState",
    "IndustryCategory",
    "MaximumUserAccess",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.analytics_admin_service import AnalyticsAdminServiceClient
from .services.analytics_admin_service import AnalyticsAdminServiceAsyncClient

from .types.analytics_admin import ArchiveCustomDimensionRequest
from .types.analytics_admin import ArchiveCustomMetricRequest
from .types.analytics_admin import AuditUserLinksRequest
from .types.analytics_admin import AuditUserLinksResponse
from .types.analytics_admin import BatchCreateUserLinksRequest
from .types.analytics_admin import BatchCreateUserLinksResponse
from .types.analytics_admin import BatchDeleteUserLinksRequest
from .types.analytics_admin import BatchGetUserLinksRequest
from .types.analytics_admin import BatchGetUserLinksResponse
from .types.analytics_admin import BatchUpdateUserLinksRequest
from .types.analytics_admin import BatchUpdateUserLinksResponse
from .types.analytics_admin import CreateConversionEventRequest
from .types.analytics_admin import CreateCustomDimensionRequest
from .types.analytics_admin import CreateCustomMetricRequest
from .types.analytics_admin import CreateFirebaseLinkRequest
from .types.analytics_admin import CreateGoogleAdsLinkRequest
from .types.analytics_admin import CreateMeasurementProtocolSecretRequest
from .types.analytics_admin import CreatePropertyRequest
from .types.analytics_admin import CreateUserLinkRequest
from .types.analytics_admin import CreateWebDataStreamRequest
from .types.analytics_admin import DeleteAccountRequest
from .types.analytics_admin import DeleteAndroidAppDataStreamRequest
from .types.analytics_admin import DeleteConversionEventRequest
from .types.analytics_admin import DeleteFirebaseLinkRequest
from .types.analytics_admin import DeleteGoogleAdsLinkRequest
from .types.analytics_admin import DeleteIosAppDataStreamRequest
from .types.analytics_admin import DeleteMeasurementProtocolSecretRequest
from .types.analytics_admin import DeletePropertyRequest
from .types.analytics_admin import DeleteUserLinkRequest
from .types.analytics_admin import DeleteWebDataStreamRequest
from .types.analytics_admin import GetAccountRequest
from .types.analytics_admin import GetAndroidAppDataStreamRequest
from .types.analytics_admin import GetConversionEventRequest
from .types.analytics_admin import GetCustomDimensionRequest
from .types.analytics_admin import GetCustomMetricRequest
from .types.analytics_admin import GetDataSharingSettingsRequest
from .types.analytics_admin import GetEnhancedMeasurementSettingsRequest
from .types.analytics_admin import GetGlobalSiteTagRequest
from .types.analytics_admin import GetGoogleSignalsSettingsRequest
from .types.analytics_admin import GetIosAppDataStreamRequest
from .types.analytics_admin import GetMeasurementProtocolSecretRequest
from .types.analytics_admin import GetPropertyRequest
from .types.analytics_admin import GetUserLinkRequest
from .types.analytics_admin import GetWebDataStreamRequest
from .types.analytics_admin import ListAccountsRequest
from .types.analytics_admin import ListAccountsResponse
from .types.analytics_admin import ListAccountSummariesRequest
from .types.analytics_admin import ListAccountSummariesResponse
from .types.analytics_admin import ListAndroidAppDataStreamsRequest
from .types.analytics_admin import ListAndroidAppDataStreamsResponse
from .types.analytics_admin import ListConversionEventsRequest
from .types.analytics_admin import ListConversionEventsResponse
from .types.analytics_admin import ListCustomDimensionsRequest
from .types.analytics_admin import ListCustomDimensionsResponse
from .types.analytics_admin import ListCustomMetricsRequest
from .types.analytics_admin import ListCustomMetricsResponse
from .types.analytics_admin import ListFirebaseLinksRequest
from .types.analytics_admin import ListFirebaseLinksResponse
from .types.analytics_admin import ListGoogleAdsLinksRequest
from .types.analytics_admin import ListGoogleAdsLinksResponse
from .types.analytics_admin import ListIosAppDataStreamsRequest
from .types.analytics_admin import ListIosAppDataStreamsResponse
from .types.analytics_admin import ListMeasurementProtocolSecretsRequest
from .types.analytics_admin import ListMeasurementProtocolSecretsResponse
from .types.analytics_admin import ListPropertiesRequest
from .types.analytics_admin import ListPropertiesResponse
from .types.analytics_admin import ListUserLinksRequest
from .types.analytics_admin import ListUserLinksResponse
from .types.analytics_admin import ListWebDataStreamsRequest
from .types.analytics_admin import ListWebDataStreamsResponse
from .types.analytics_admin import ProvisionAccountTicketRequest
from .types.analytics_admin import ProvisionAccountTicketResponse
from .types.analytics_admin import SearchChangeHistoryEventsRequest
from .types.analytics_admin import SearchChangeHistoryEventsResponse
from .types.analytics_admin import UpdateAccountRequest
from .types.analytics_admin import UpdateAndroidAppDataStreamRequest
from .types.analytics_admin import UpdateCustomDimensionRequest
from .types.analytics_admin import UpdateCustomMetricRequest
from .types.analytics_admin import UpdateEnhancedMeasurementSettingsRequest
from .types.analytics_admin import UpdateFirebaseLinkRequest
from .types.analytics_admin import UpdateGoogleAdsLinkRequest
from .types.analytics_admin import UpdateGoogleSignalsSettingsRequest
from .types.analytics_admin import UpdateIosAppDataStreamRequest
from .types.analytics_admin import UpdateMeasurementProtocolSecretRequest
from .types.analytics_admin import UpdatePropertyRequest
from .types.analytics_admin import UpdateUserLinkRequest
from .types.analytics_admin import UpdateWebDataStreamRequest
from .types.resources import Account
from .types.resources import AccountSummary
from .types.resources import AndroidAppDataStream
from .types.resources import AuditUserLink
from .types.resources import ChangeHistoryChange
from .types.resources import ChangeHistoryEvent
from .types.resources import ConversionEvent
from .types.resources import CustomDimension
from .types.resources import CustomMetric
from .types.resources import DataSharingSettings
from .types.resources import EnhancedMeasurementSettings
from .types.resources import FirebaseLink
from .types.resources import GlobalSiteTag
from .types.resources import GoogleAdsLink
from .types.resources import GoogleSignalsSettings
from .types.resources import IosAppDataStream
from .types.resources import MeasurementProtocolSecret
from .types.resources import Property
from .types.resources import PropertySummary
from .types.resources import UserLink
from .types.resources import WebDataStream
from .types.resources import ActionType
from .types.resources import ActorType
from .types.resources import ChangeHistoryResourceType
from .types.resources import GoogleSignalsConsent
from .types.resources import GoogleSignalsState
from .types.resources import IndustryCategory
from .types.resources import MaximumUserAccess

__all__ = (
    "AnalyticsAdminServiceAsyncClient",
    "Account",
    "AccountSummary",
    "ActionType",
    "ActorType",
    "AnalyticsAdminServiceClient",
    "AndroidAppDataStream",
    "ArchiveCustomDimensionRequest",
    "ArchiveCustomMetricRequest",
    "AuditUserLink",
    "AuditUserLinksRequest",
    "AuditUserLinksResponse",
    "BatchCreateUserLinksRequest",
    "BatchCreateUserLinksResponse",
    "BatchDeleteUserLinksRequest",
    "BatchGetUserLinksRequest",
    "BatchGetUserLinksResponse",
    "BatchUpdateUserLinksRequest",
    "BatchUpdateUserLinksResponse",
    "ChangeHistoryChange",
    "ChangeHistoryEvent",
    "ChangeHistoryResourceType",
    "ConversionEvent",
    "CreateConversionEventRequest",
    "CreateCustomDimensionRequest",
    "CreateCustomMetricRequest",
    "CreateFirebaseLinkRequest",
    "CreateGoogleAdsLinkRequest",
    "CreateMeasurementProtocolSecretRequest",
    "CreatePropertyRequest",
    "CreateUserLinkRequest",
    "CreateWebDataStreamRequest",
    "CustomDimension",
    "CustomMetric",
    "DataSharingSettings",
    "DeleteAccountRequest",
    "DeleteAndroidAppDataStreamRequest",
    "DeleteConversionEventRequest",
    "DeleteFirebaseLinkRequest",
    "DeleteGoogleAdsLinkRequest",
    "DeleteIosAppDataStreamRequest",
    "DeleteMeasurementProtocolSecretRequest",
    "DeletePropertyRequest",
    "DeleteUserLinkRequest",
    "DeleteWebDataStreamRequest",
    "EnhancedMeasurementSettings",
    "FirebaseLink",
    "GetAccountRequest",
    "GetAndroidAppDataStreamRequest",
    "GetConversionEventRequest",
    "GetCustomDimensionRequest",
    "GetCustomMetricRequest",
    "GetDataSharingSettingsRequest",
    "GetEnhancedMeasurementSettingsRequest",
    "GetGlobalSiteTagRequest",
    "GetGoogleSignalsSettingsRequest",
    "GetIosAppDataStreamRequest",
    "GetMeasurementProtocolSecretRequest",
    "GetPropertyRequest",
    "GetUserLinkRequest",
    "GetWebDataStreamRequest",
    "GlobalSiteTag",
    "GoogleAdsLink",
    "GoogleSignalsConsent",
    "GoogleSignalsSettings",
    "GoogleSignalsState",
    "IndustryCategory",
    "IosAppDataStream",
    "ListAccountSummariesRequest",
    "ListAccountSummariesResponse",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "ListAndroidAppDataStreamsRequest",
    "ListAndroidAppDataStreamsResponse",
    "ListConversionEventsRequest",
    "ListConversionEventsResponse",
    "ListCustomDimensionsRequest",
    "ListCustomDimensionsResponse",
    "ListCustomMetricsRequest",
    "ListCustomMetricsResponse",
    "ListFirebaseLinksRequest",
    "ListFirebaseLinksResponse",
    "ListGoogleAdsLinksRequest",
    "ListGoogleAdsLinksResponse",
    "ListIosAppDataStreamsRequest",
    "ListIosAppDataStreamsResponse",
    "ListMeasurementProtocolSecretsRequest",
    "ListMeasurementProtocolSecretsResponse",
    "ListPropertiesRequest",
    "ListPropertiesResponse",
    "ListUserLinksRequest",
    "ListUserLinksResponse",
    "ListWebDataStreamsRequest",
    "ListWebDataStreamsResponse",
    "MaximumUserAccess",
    "MeasurementProtocolSecret",
    "Property",
    "PropertySummary",
    "ProvisionAccountTicketRequest",
    "ProvisionAccountTicketResponse",
    "SearchChangeHistoryEventsRequest",
    "SearchChangeHistoryEventsResponse",
    "UpdateAccountRequest",
    "UpdateAndroidAppDataStreamRequest",
    "UpdateCustomDimensionRequest",
    "UpdateCustomMetricRequest",
    "UpdateEnhancedMeasurementSettingsRequest",
    "UpdateFirebaseLinkRequest",
    "UpdateGoogleAdsLinkRequest",
    "UpdateGoogleSignalsSettingsRequest",
    "UpdateIosAppDataStreamRequest",
    "UpdateMeasurementProtocolSecretRequest",
    "UpdatePropertyRequest",
    "UpdateUserLinkRequest",
    "UpdateWebDataStreamRequest",
    "UserLink",
    "WebDataStream",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.analytics.admin_v1alpha.types import resources
from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.analytics.admin.v1alpha",
    manifest={
        "GetAccountRequest",
        "ListAccountsRequest",
        "ListAccountsResponse",
        "DeleteAccountRequest",
        "UpdateAccountRequest",
        "ProvisionAccountTicketRequest",
        "ProvisionAccountTicketResponse",
        "GetPropertyRequest",
        "ListPropertiesRequest",
        "ListPropertiesResponse",
        "UpdatePropertyRequest",
        "CreatePropertyRequest",
        "DeletePropertyRequest",
        "GetUserLinkRequest",
        "BatchGetUserLinksRequest",
        "BatchGetUserLinksResponse",
        "ListUserLinksRequest",
        "ListUserLinksResponse",
        "AuditUserLinksRequest",
        "AuditUserLinksResponse",
        "CreateUserLinkRequest",
        "BatchCreateUserLinksRequest",
        "BatchCreateUserLinksResponse",
        "UpdateUserLinkRequest",
        "BatchUpdateUserLinksRequest",
        "BatchUpdateUserLinksResponse",
        "DeleteUserLinkRequest",
        "BatchDeleteUserLinksRequest",
        "GetWebDataStreamRequest",
        "DeleteWebDataStreamRequest",
        "UpdateWebDataStreamRequest",
        "CreateWebDataStreamRequest",
        "ListWebDataStreamsRequest",
        "ListWebDataStreamsResponse",
        "GetIosAppDataStreamRequest",
        "DeleteIosAppDataStreamRequest",
        "UpdateIosAppDataStreamRequest",
        "ListIosAppDataStreamsRequest",
        "ListIosAppDataStreamsResponse",
        "GetAndroidAppDataStreamRequest",
        "DeleteAndroidAppDataStreamRequest",
        "UpdateAndroidAppDataStreamRequest",
        "ListAndroidAppDataStreamsRequest",
        "ListAndroidAppDataStreamsResponse",
        "GetEnhancedMeasurementSettingsRequest",
        "UpdateEnhancedMeasurementSettingsRequest",
        "CreateFirebaseLinkRequest",
        "UpdateFirebaseLinkRequest",
        "DeleteFirebaseLinkRequest",
        "ListFirebaseLinksRequest",
        "ListFirebaseLinksResponse",
        "GetGlobalSiteTagRequest",
        "CreateGoogleAdsLinkRequest",
        "UpdateGoogleAdsLinkRequest",
        "DeleteGoogleAdsLinkRequest",
        "ListGoogleAdsLinksRequest",
        "ListGoogleAdsLinksResponse",
        "GetDataSharingSettingsRequest",
        "ListAccountSummariesRequest",
        "ListAccountSummariesResponse",
        "SearchChangeHistoryEventsRequest",
        "SearchChangeHistoryEventsResponse",
        "GetMeasurementProtocolSecretRequest",
        "CreateMeasurementProtocolSecretRequest",
        "DeleteMeasurementProtocolSecretRequest",
        "UpdateMeasurementProtocolSecretRequest",
        "ListMeasurementProtocolSecretsRequest",
        "ListMeasurementProtocolSecretsResponse",
        "GetGoogleSignalsSettingsRequest",
        "UpdateGoogleSignalsSettingsRequest",
        "CreateConversionEventRequest",
        "GetConversionEventRequest",
        "DeleteConversionEventRequest",
        "ListConversionEventsRequest",
        "ListConversionEventsResponse",
        "CreateCustomDimensionRequest",
        "UpdateCustomDimensionRequest",
        "ListCustomDimensionsRequest",
        "ListCustomDimensionsResponse",
        "ArchiveCustomDimensionRequest",
        "GetCustomDimensionRequest",
        "CreateCustomMetricRequest",
        "UpdateCustomMetricRequest",
        "ListCustomMetricsRequest",
        "ListCustomMetricsResponse",
        "ArchiveCustomMetricRequest",
        "GetCustomMetricRequest",
    },
)


class GetAccountRequest(proto.Message):
    r"""Request message for GetAccount RPC.
    Attributes:
        name (str):
            Required. The name of the account to lookup.
            Format: accounts/{account}
            Example: "accounts/100".
    """

    name = proto.Field(proto.STRING, number=1,)


class ListAccountsRequest(proto.Message):
    r"""Request message for ListAccounts RPC.
    Attributes:
        page_size (int):
            The maximum number of resources to return.
            The service may return fewer than this value,
            even if there are additional pages. If
            unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous ``ListAccounts``
            call. Provide this to retrieve the subsequent page. When
            paginating, all other parameters provided to
            ``ListAccounts`` must match the call that provided the page
            token.
        show_deleted (bool):
            Whether to include soft-deleted (ie:
            "trashed") Accounts in the results. Accounts can
            be inspected to determine whether they are
            deleted or not.
    """

    page_size = proto.Field(proto.INT32, number=1,)
    page_token = proto.Field(proto.STRING, number=2,)
    show_deleted = proto.Field(proto.BOOL, number=3,)


class ListAccountsResponse(proto.Message):
    r"""Request message for ListAccounts RPC.
    Attributes:
        accounts (Sequence[google.analytics.admin_v1alpha.types.Account]):
            Results that were accessible to the caller.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    accounts = proto.RepeatedField(proto.MESSAGE, number=1, message=resources.Account,)
    next_page_token = proto.Field(proto.STRING, number=2,)


class DeleteAccountRequest(proto.Message):
    r"""Request message for DeleteAccount RPC.
    Attributes:
        name (str):
            Required. The name of the Account to soft-
            elete. Format: accounts/{account}
            Example: "accounts/100".
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateAccountRequest(proto.Message):
    r"""Request message for UpdateAccount RPC.
    Attributes:
        account (google.analytics.admin_v1alpha.types.Account):
            Required. The account to update. The account's ``name``
            field is used to identify the account.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    account = proto.Field(proto.MESSAGE, number=1, message=resources.Account,)
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class ProvisionAccountTicketRequest(proto.Message):
    r"""Request message for ProvisionAccountTicket RPC.
    Attributes:
        account (google.analytics.admin_v1alpha.types.Account):
            The account to create.
        redirect_uri (str):
            Redirect URI where the user will be sent
            after accepting Terms of Service. Must be
            configured in Developers Console as a Redirect
            URI
    """

    account = proto.Field(proto.MESSAGE, number=1, message=resources.Account,)
    redirect_uri = proto.Field(proto.STRING, number=2,)


class ProvisionAccountTicketResponse(proto.Message):
    r"""Response message for ProvisionAccountTicket RPC.
    Attributes:
        account_ticket_id (str):
            The param to be passed in the ToS link.
    """

    account_ticket_id = proto.Field(proto.STRING, number=1,)


class GetPropertyRequest(proto.Message):
    r"""Request message for GetProperty RPC.
    Attributes:
        name (str):
            Required. The name of the property to lookup. Format:
            properties/{property_id} Example: "properties/1000".
    """

    name = proto.Field(proto.STRING, number=1,)


class ListPropertiesRequest(proto.Message):
    r"""Request message for ListProperties RPC.
    Attributes:
        filter (str):
            Required. An expression for filtering the results of the
            request. Fields eligible for filtering are:
            ``parent:``\ (The resource name of the parent account) or
            ``firebase_project:``\ (The id or number of the linked
            firebase project). Some examples of filters:

            ::

               | Filter                      | Description                               |
               |-----------------------------|-------------------------------------------|
               | parent:accounts/123         | The account with account id: 123.         |
               | firebase_project:project-id | The firebase project with id: project-id. |
               | firebase_project:123        | The firebase project with number: 123.    |
        page_size (int):
            The maximum number of resources to return.
            The service may return fewer than this value,
            even if there are additional pages. If
            unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous ``ListProperties``
            call. Provide this to retrieve the subsequent page. When
            paginating, all other parameters provided to
            ``ListProperties`` must match the call that provided the
            page token.
        show_deleted (bool):
            Whether to include soft-deleted (ie:
            "trashed") Properties in the results. Properties
            can be inspected to determine whether they are
            deleted or not.
    """

    filter = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)
    show_deleted = proto.Field(proto.BOOL, number=4,)


class ListPropertiesResponse(proto.Message):
    r"""Response message for ListProperties RPC.
    Attributes:
        properties (Sequence[google.analytics.admin_v1alpha.types.Property]):
            Results that matched the filter criteria and
            were accessible to the caller.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    properties = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.Property,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class UpdatePropertyRequest(proto.Message):
    r"""Request message for UpdateProperty RPC.
    Attributes:
        property (google.analytics.admin_v1alpha.types.Property):
            Required. The property to update. The property's ``name``
            field is used to identify the property to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    property = proto.Field(proto.MESSAGE, number=1, message=resources.Property,)
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class CreatePropertyRequest(proto.Message):
    r"""Request message for CreateProperty RPC.
    Attributes:
        property (google.analytics.admin_v1alpha.types.Property):
            Required. The property to create.
            Note: the supplied property must specify its
            parent.
    """

    property = proto.Field(proto.MESSAGE, number=1, message=resources.Property,)


class DeletePropertyRequest(proto.Message):
    r"""Request message for DeleteProperty RPC.
    Attributes:
        name (str):
            Required. The name of the Property to soft-delete. Format:
            properties/{property_id} Example: "properties/1000".
    """

    name = proto.Field(proto.STRING, number=1,)


class GetUserLinkRequest(proto.Message):
    r"""Request message for GetUserLink RPC.
    Attributes:
        name (str):
            Required. Example format:
            accounts/1234/userLinks/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class BatchGetUserLinksRequest(proto.Message):
    r"""Request message for BatchGetUserLinks RPC.
    Attributes:
        parent (str):
            Required. The account or property that all
            user links in the request are for. The parent of
            all provided values for the 'names' field must
            match this field.
            Example format: accounts/1234
        names (Sequence[str]):
            Required. The names of the user links to
            retrieve. A maximum of 1000 user links can be
            retrieved in a batch. Format:
            accounts/{accountId}/userLinks/{userLinkId}
    """

    parent = proto.Field(proto.STRING, number=1,)
    names = proto.RepeatedField(proto.STRING, number=2,)


class BatchGetUserLinksResponse(proto.Message):
    r"""Response message for BatchGetUserLinks RPC.
    Attributes:
        user_links (Sequence[google.analytics.admin_v1alpha.types.UserLink]):
            The requested user links.
    """

    user_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.UserLink,
    )


class ListUserLinksRequest(proto.Message):
    r"""Request message for ListUserLinks RPC.
    Attributes:
        parent (str):
            Required. Example format: accounts/1234
        page_size (int):
            The maximum number of user links to return.
            The service may return fewer than this value. If
            unspecified, at most 200 user links will be
            returned. The maximum value is 500; values above
            500 will be coerced to 500.
        page_token (str):
            A page token, received from a previous ``ListUserLinks``
            call. Provide this to retrieve the subsequent page. When
            paginating, all other parameters provided to
            ``ListUserLinks`` must match the call that provided the page
            token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListUserLinksResponse(proto.Message):
    r"""Response message for ListUserLinks RPC.
    Attributes:
        user_links (Sequence[google.analytics.admin_v1alpha.types.UserLink]):
            List of UserLinks. These will be ordered
            stably, but in an arbitrary order.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    user_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.UserLink,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class AuditUserLinksRequest(proto.Message):
    r"""Request message for AuditUserLinks RPC.
    Attributes:
        parent (str):
            Required. Example format: accounts/1234
        page_size (int):
            The maximum number of user links to return.
            The service may return fewer than this value. If
            unspecified, at most 1000 user links will be
            returned. The maximum value is 5000; values
            above 5000 will be coerced to 5000.
        page_token (str):
            A page token, received from a previous ``AuditUserLinks``
            call. Provide this to retrieve the subsequent page. When
            paginating, all other parameters provided to
            ``AuditUserLinks`` must match the call that provided the
            page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class AuditUserLinksResponse(proto.Message):
    r"""Response message for AuditUserLinks RPC.
    Attributes:
        user_links (Sequence[google.analytics.admin_v1alpha.types.AuditUserLink]):
            List of AuditUserLinks. These will be ordered
            stably, but in an arbitrary order.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    user_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.AuditUserLink,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class CreateUserLinkRequest(proto.Message):
    r"""Request message for CreateUserLink RPC.
    Users can have multiple email addresses associated with their
    Google account, and one of these email addresses is the
    "primary" email address. Any of the email addresses associated
    with a Google account may be used for a new UserLink, but the
    returned UserLink will always contain the "primary" email
    address. As a result, the input and output email address for
    this request may differ.

    Attributes:
        parent (str):
            Required. Example format: accounts/1234
        notify_new_user (bool):
            Optional. If set, then email the new user
            notifying them that they've been granted
            permissions to the resource.
        user_link (google.analytics.admin_v1alpha.types.UserLink):
            Required. The user link to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    notify_new_user = proto.Field(proto.BOOL, number=2,)
    user_link = proto.Field(proto.MESSAGE, number=3, message=resources.UserLink,)


class BatchCreateUserLinksRequest(proto.Message):
    r"""Request message for BatchCreateUserLinks RPC.
    Attributes:
        parent (str):
            Required. The account or property that all
            user links in the request are for. This field is
            required. The parent field in the
            CreateUserLinkRequest messages must either be
            empty or match this field. Example format:
            accounts/1234
        notify_new_users (bool):
            Optional. If set, then email the new users notifying them
            that they've been granted permissions to the resource.
            Regardless of whether this is set or not, notify_new_user
            field inside each individual request is ignored.
        requests (Sequence[google.analytics.admin_v1alpha.types.CreateUserLinkRequest]):
            Required. The requests specifying the user
            links to create. A maximum of 1000 user links
            can be created in a batch.
    """

    parent = proto.Field(proto.STRING, number=1,)
    notify_new_users = proto.Field(proto.BOOL, number=2,)
    requests = proto.RepeatedField(
        proto.MESSAGE, number=3, message="CreateUserLinkRequest",
    )


class BatchCreateUserLinksResponse(proto.Message):
    r"""Response message for BatchCreateUserLinks RPC.
    Attributes:
        user_links (Sequence[google.analytics.admin_v1alpha.types.UserLink]):
            The user links created.
    """

    user_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.UserLink,
    )


class UpdateUserLinkRequest(proto.Message):
    r"""Request message for UpdateUserLink RPC.
    Attributes:
        user_link (google.analytics.admin_v1alpha.types.UserLink):
            Required. The user link to update.
    """

    user_link = proto.Field(proto.MESSAGE, number=1, message=resources.UserLink,)


class BatchUpdateUserLinksRequest(proto.Message):
    r"""Request message for BatchUpdateUserLinks RPC.
    Attributes:
        parent (str):
            Required. The account or property that all
            user links in the request are for. The parent
            field in the UpdateUserLinkRequest messages must
            either be empty or match this field.
            Example format: accounts/1234
        requests (Sequence[google.analytics.admin_v1alpha.types.UpdateUserLinkRequest]):
            Required. The requests specifying the user
            links to update. A maximum of 1000 user links
            can be updated in a batch.
    """

    parent = proto.Field(proto.STRING, number=1,)
    requests = proto.RepeatedField(
        proto.MESSAGE, number=2, message="UpdateUserLinkRequest",
    )


class BatchUpdateUserLinksResponse(proto.Message):
    r"""Response message for BatchUpdateUserLinks RPC.
    Attributes:
        user_links (Sequence[google.analytics.admin_v1alpha.types.UserLink]):
            The user links updated.
    """

    user_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.UserLink,
    )


class DeleteUserLinkRequest(proto.Message):
    r"""Request message for DeleteUserLink RPC.
    Attributes:
        name (str):
            Required. Example format:
            accounts/1234/userLinks/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class BatchDeleteUserLinksRequest(proto.Message):
    r"""Request message for BatchDeleteUserLinks RPC.
    Attributes:
        parent (str):
            Required. The account or property that all
            user links in the request are for. The parent of
            all values for user link names to delete must
            match this field.
            Example format: accounts/1234
        requests (Sequence[google.analytics.admin_v1alpha.types.DeleteUserLinkRequest]):
            Required. The requests specifying the user
            links to update. A maximum of 1000 user links
            can be updated in a batch.
    """

    parent = proto.Field(proto.STRING, number=1,)
    requests = proto.RepeatedField(
        proto.MESSAGE, number=2, message="DeleteUserLinkRequest",
    )


class GetWebDataStreamRequest(proto.Message):
    r"""Request message for GetWebDataStream RPC.
    Attributes:
        name (str):
            Required. The name of the web data stream to lookup. Format:
            properties/{property_id}/webDataStreams/{stream_id} Example:
            "properties/123/webDataStreams/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteWebDataStreamRequest(proto.Message):
    r"""Request message for DeleteWebDataStream RPC.
    Attributes:
        name (str):
            Required. The name of the web data stream to delete. Format:
            properties/{property_id}/webDataStreams/{stream_id} Example:
            "properties/123/webDataStreams/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateWebDataStreamRequest(proto.Message):
    r"""Request message for UpdateWebDataStream RPC.
    Attributes:
        web_data_stream (google.analytics.admin_v1alpha.types.WebDataStream):
            Required. The web stream to update. The ``name`` field is
            used to identify the web stream to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    web_data_stream = proto.Field(
        proto.MESSAGE, number=1, message=resources.WebDataStream,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class CreateWebDataStreamRequest(proto.Message):
    r"""Request message for CreateWebDataStream RPC.
    Attributes:
        web_data_stream (google.analytics.admin_v1alpha.types.WebDataStream):
            Required. The web stream to create.
        parent (str):
            Required. The parent resource where this web
            data stream will be created. Format:
            properties/123
    """

    web_data_stream = proto.Field(
        proto.MESSAGE, number=1, message=resources.WebDataStream,
    )
    parent = proto.Field(proto.STRING, number=2,)


class ListWebDataStreamsRequest(proto.Message):
    r"""Request message for ListWebDataStreams RPC.
    Attributes:
        parent (str):
            Required. The name of the parent property.
            For example, to list results of web streams
            under the property with Id 123: "properties/123".
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous
            ``ListWebDataStreams`` call. Provide this to retrieve the
            subsequent page. When paginating, all other parameters
            provided to ``ListWebDataStreams`` must match the call that
            provided the page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListWebDataStreamsResponse(proto.Message):
    r"""Request message for ListWebDataStreams RPC.
    Attributes:
        web_data_streams (Sequence[google.analytics.admin_v1alpha.types.WebDataStream]):
            Results that matched the filter criteria and
            were accessible to the caller.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    web_data_streams = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.WebDataStream,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetIosAppDataStreamRequest(proto.Message):
    r"""Request message for GetIosAppDataStream RPC.
    Attributes:
        name (str):
            Required. The name of the iOS app data stream to lookup.
            Format:
            properties/{property_id}/iosAppDataStreams/{stream_id}
            Example: "properties/123/iosAppDataStreams/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteIosAppDataStreamRequest(proto.Message):
    r"""Request message for DeleteIosAppDataStream RPC.
    Attributes:
        name (str):
            Required. The name of the iOS app data stream to delete.
            Format:
            properties/{property_id}/iosAppDataStreams/{stream_id}
            Example: "properties/123/iosAppDataStreams/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateIosAppDataStreamRequest(proto.Message):
    r"""Request message for UpdateIosAppDataStream RPC.
    Attributes:
        ios_app_data_stream (google.analytics.admin_v1alpha.types.IosAppDataStream):
            Required. The iOS app stream to update. The ``name`` field
            is used to identify the iOS app stream to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    ios_app_data_stream = proto.Field(
        proto.MESSAGE, number=1, message=resources.IosAppDataStream,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class ListIosAppDataStreamsRequest(proto.Message):
    r"""Request message for ListIosAppDataStreams RPC.
    Attributes:
        parent (str):
            Required. The name of the parent property.
            For example, to list results of app streams
            under the property with Id 123: "properties/123".
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous
            ``ListIosAppDataStreams`` call. Provide this to retrieve the
            subsequent page. When paginating, all other parameters
            provided to ``ListIosAppDataStreams`` must match the call
            that provided the page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListIosAppDataStreamsResponse(proto.Message):
    r"""Request message for ListIosAppDataStreams RPC.
    Attributes:
        ios_app_data_streams (Sequence[google.analytics.admin_v1alpha.types.IosAppDataStream]):
            Results that matched the filter criteria and
            were accessible to the caller.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    ios_app_data_streams = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.IosAppDataStream,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetAndroidAppDataStreamRequest(proto.Message):
    r"""Request message for GetAndroidAppDataStream RPC.
    Attributes:
        name (str):
            Required. The name of the android app data stream to lookup.
            Format:
            properties/{property_id}/androidAppDataStreams/{stream_id}
            Example: "properties/123/androidAppDataStreams/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteAndroidAppDataStreamRequest(proto.Message):
    r"""Request message for DeleteAndroidAppDataStream RPC.
    Attributes:
        name (str):
            Required. The name of the android app data stream to delete.
            Format:
            properties/{property_id}/androidAppDataStreams/{stream_id}
            Example: "properties/123/androidAppDataStreams/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateAndroidAppDataStreamRequest(proto.Message):
    r"""Request message for UpdateAndroidAppDataStream RPC.
    Attributes:
        android_app_data_stream (google.analytics.admin_v1alpha.types.AndroidAppDataStream):
            Required. The android app stream to update. The ``name``
            field is used to identify the android app stream to be
            updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    android_app_data_stream = proto.Field(
        proto.MESSAGE, number=1, message=resources.AndroidAppDataStream,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class ListAndroidAppDataStreamsRequest(proto.Message):
    r"""Request message for ListAndroidAppDataStreams RPC.
    Attributes:
        parent (str):
            Required. The name of the parent property.
            For example, to limit results to app streams
            under the property with Id 123: "properties/123".
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous call. Provide this to
            retrieve the subsequent page. When paginating, all other
            parameters provided to ``ListAndroidAppDataStreams`` must
            match the call that provided the page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListAndroidAppDataStreamsResponse(proto.Message):
    r"""Request message for ListAndroidDataStreams RPC.
    Attributes:
        android_app_data_streams (Sequence[google.analytics.admin_v1alpha.types.AndroidAppDataStream]):
            Results that matched the filter criteria and
            were accessible to the caller.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    android_app_data_streams = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.AndroidAppDataStream,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetEnhancedMeasurementSettingsRequest(proto.Message):
    r"""Request message for GetEnhancedMeasurementSettings RPC.
    Attributes:
        name (str):
            Required. The name of the settings to lookup. Format:
            properties/{property_id}/webDataStreams/{stream_id}/enhancedMeasurementSettings
            Example:
            "properties/1000/webDataStreams/2000/enhancedMeasurementSettings".
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateEnhancedMeasurementSettingsRequest(proto.Message):
    r"""Request message for UpdateEnhancedMeasurementSettings RPC.
    Attributes:
        enhanced_measurement_settings (google.analytics.admin_v1alpha.types.EnhancedMeasurementSettings):
            Required. The settings to update. The ``name`` field is used
            to identify the settings to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    enhanced_measurement_settings = proto.Field(
        proto.MESSAGE, number=1, message=resources.EnhancedMeasurementSettings,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class CreateFirebaseLinkRequest(proto.Message):
    r"""Request message for CreateFirebaseLink RPC
    Attributes:
        parent (str):
            Required. Format: properties/{property_id} Example:
            properties/1234
        firebase_link (google.analytics.admin_v1alpha.types.FirebaseLink):
            Required. The Firebase link to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    firebase_link = proto.Field(
        proto.MESSAGE, number=2, message=resources.FirebaseLink,
    )


class UpdateFirebaseLinkRequest(proto.Message):
    r"""Request message for UpdateFirebaseLink RPC
    Attributes:
        firebase_link (google.analytics.admin_v1alpha.types.FirebaseLink):
            Required. The Firebase link to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    firebase_link = proto.Field(
        proto.MESSAGE, number=1, message=resources.FirebaseLink,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class DeleteFirebaseLinkRequest(proto.Message):
    r"""Request message for DeleteFirebaseLink RPC
    Attributes:
        name (str):
            Required. Format:
            properties/{property_id}/firebaseLinks/{firebase_link_id}
            Example: properties/1234/firebaseLinks/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class ListFirebaseLinksRequest(proto.Message):
    r"""Request message for ListFirebaseLinks RPC
    Attributes:
        parent (str):
            Required. Format: properties/{property_id} Example:
            properties/1234
        page_size (int):
            The maximum number of resources to return.
            The service may return fewer than this value,
            even if there are additional pages. If
            unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous ``ListFirebaseLinks``
            call. Provide this to retrieve the subsequent page. When
            paginating, all other parameters provided to
            ``ListProperties`` must match the call that provided the
            page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListFirebaseLinksResponse(proto.Message):
    r"""Response message for ListFirebaseLinks RPC
    Attributes:
        firebase_links (Sequence[google.analytics.admin_v1alpha.types.FirebaseLink]):
            List of FirebaseLinks. This will have at most
            one value.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages. Currently, Google Analytics supports only one
            FirebaseLink per property, so this will never be populated.
    """

    @property
    def raw_page(self):
        return self

    firebase_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.FirebaseLink,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetGlobalSiteTagRequest(proto.Message):
    r"""Request message for GetGlobalSiteTag RPC.
    Attributes:
        name (str):
            Required. The name of the site tag to lookup. Note that site
            tags are singletons and do not have unique IDs. Format:
            properties/{property_id}/webDataStreams/{stream_id}/globalSiteTag
            Example: "properties/123/webDataStreams/456/globalSiteTag".
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateGoogleAdsLinkRequest(proto.Message):
    r"""Request message for CreateGoogleAdsLink RPC
    Attributes:
        parent (str):
            Required. Example format: properties/1234
        google_ads_link (google.analytics.admin_v1alpha.types.GoogleAdsLink):
            Required. The GoogleAdsLink to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    google_ads_link = proto.Field(
        proto.MESSAGE, number=2, message=resources.GoogleAdsLink,
    )


class UpdateGoogleAdsLinkRequest(proto.Message):
    r"""Request message for UpdateGoogleAdsLink RPC
    Attributes:
        google_ads_link (google.analytics.admin_v1alpha.types.GoogleAdsLink):
            The GoogleAdsLink to update
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    google_ads_link = proto.Field(
        proto.MESSAGE, number=1, message=resources.GoogleAdsLink,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class DeleteGoogleAdsLinkRequest(proto.Message):
    r"""Request message for DeleteGoogleAdsLink RPC.
    Attributes:
        name (str):
            Required. Example format:
            properties/1234/googleAdsLinks/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class ListGoogleAdsLinksRequest(proto.Message):
    r"""Request message for ListGoogleAdsLinks RPC.
    Attributes:
        parent (str):
            Required. Example format: properties/1234
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200 (higher
            values will be coerced to the maximum).
        page_token (str):
            A page token, received from a previous
            ``ListGoogleAdsLinks`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListGoogleAdsLinks`` must match the call that provided the
            page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListGoogleAdsLinksResponse(proto.Message):
    r"""Response message for ListGoogleAdsLinks RPC.
    Attributes:
        google_ads_links (Sequence[google.analytics.admin_v1alpha.types.GoogleAdsLink]):
            List of GoogleAdsLinks.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    google_ads_links = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.GoogleAdsLink,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetDataSharingSettingsRequest(proto.Message):
    r"""Request message for GetDataSharingSettings RPC.
    Attributes:
        name (str):
            Required. The name of the settings to lookup.
            Format: accounts/{account}/dataSharingSettings
            Example: "accounts/1000/dataSharingSettings".
    """

    name = proto.Field(proto.STRING, number=1,)


class ListAccountSummariesRequest(proto.Message):
    r"""Request message for ListAccountSummaries RPC.
    Attributes:
        page_size (int):
            The maximum number of AccountSummary
            resources to return. The service may return
            fewer than this value, even if there are
            additional pages. If unspecified, at most 50
            resources will be returned. The maximum value is
            200; (higher values will be coerced to the
            maximum)
        page_token (str):
            A page token, received from a previous
            ``ListAccountSummaries`` call. Provide this to retrieve the
            subsequent page. When paginating, all other parameters
            provided to ``ListAccountSummaries`` must match the call
            that provided the page token.
    """

    page_size = proto.Field(proto.INT32, number=1,)
    page_token = proto.Field(proto.STRING, number=2,)


class ListAccountSummariesResponse(proto.Message):
    r"""Response message for ListAccountSummaries RPC.
    Attributes:
        account_summaries (Sequence[google.analytics.admin_v1alpha.types.AccountSummary]):
            Account summaries of all accounts the caller
            has access to.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    account_summaries = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.AccountSummary,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class SearchChangeHistoryEventsRequest(proto.Message):
    r"""Request message for SearchChangeHistoryEvents RPC.
    Attributes:
        account (str):
            Required. The account resource for which to
            return change history resources.
        property (str):
            Optional. Resource name for a child property.
            If set, only return changes made to this
            property or its child resources.
        resource_type (Sequence[google.analytics.admin_v1alpha.types.ChangeHistoryResourceType]):
            Optional. If set, only return changes if they
            are for a resource that matches at least one of
            these types.
        action (Sequence[google.analytics.admin_v1alpha.types.ActionType]):
            Optional. If set, only return changes that
            match one or more of these types of actions.
        actor_email (Sequence[str]):
            Optional. If set, only return changes if they
            are made by a user in this list.
        earliest_change_time (google.protobuf.timestamp_pb2.Timestamp):
            Optional. If set, only return changes made
            after this time (inclusive).
        latest_change_time (google.protobuf.timestamp_pb2.Timestamp):
            Optional. If set, only return changes made
            before this time (inclusive).
        page_size (int):
            Optional. The maximum number of
            ChangeHistoryEvent items to return. The service
            may return fewer than this value, even if there
            are additional pages. If unspecified, at most 50
            items will be returned. The maximum value is 200
            (higher values will be coerced to the maximum).
        page_token (str):
            Optional. A page token, received from a previous
            ``SearchChangeHistoryEvents`` call. Provide this to retrieve
            the subsequent page. When paginating, all other parameters
            provided to ``SearchChangeHistoryEvents`` must match the
            call that provided the page token.
    """

    account = proto.Field(proto.STRING, number=1,)
    property = proto.Field(proto.STRING, number=2,)
    resource_type = proto.RepeatedField(
        proto.ENUM, number=3, enum=resources.ChangeHistoryResourceType,
    )
    action = proto.RepeatedField(proto.ENUM, number=4, enum=resources.ActionType,)
    actor_email = proto.RepeatedField(proto.STRING, number=5,)
    earliest_change_time = proto.Field(
        proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
    )
    latest_change_time = proto.Field(
        proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,
    )
    page_size = proto.Field(proto.INT32, number=8,)
    page_token = proto.Field(proto.STRING, number=9,)


class SearchChangeHistoryEventsResponse(proto.Message):
    r"""Response message for SearchAccounts RPC.
    Attributes:
        change_history_events (Sequence[google.analytics.admin_v1alpha.types.ChangeHistoryEvent]):
            Results that were accessible to the caller.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    change_history_events = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.ChangeHistoryEvent,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetMeasurementProtocolSecretRequest(proto.Message):
    r"""Request message for GetMeasurementProtocolSecret RPC.
    Attributes:
        name (str):
            Required. The name of the measurement
            protocol secret to lookup. Format:
            properties/{property}/webDataStreams/{webDataStream}/measurementProtocolSecrets/{measurementProtocolSecret}
            Note: Any type of stream (WebDataStream,
            IosAppDataStream, AndroidAppDataStream) may be a
            parent.
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateMeasurementProtocolSecretRequest(proto.Message):
    r"""Request message for CreateMeasurementProtocolSecret RPC
    Attributes:
        parent (str):
            Required. The parent resource where this
            secret will be created. Any type of stream
            (WebDataStream, IosAppDataStream,
            AndroidAppDataStream) may be a parent.
            Format:
            properties/{property}/webDataStreams/{webDataStream}
        measurement_protocol_secret (google.analytics.admin_v1alpha.types.MeasurementProtocolSecret):
            Required. The measurement protocol secret to
            create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    measurement_protocol_secret = proto.Field(
        proto.MESSAGE, number=2, message=resources.MeasurementProtocolSecret,
    )


class DeleteMeasurementProtocolSecretRequest(proto.Message):
    r"""Request message for DeleteMeasurementProtocolSecret RPC
    Attributes:
        name (str):
            Required. The name of the
            MeasurementProtocolSecret to delete. Format:
            properties/{property}/webDataStreams/{webDataStream}/measurementProtocolSecrets/{measurementProtocolSecret}
            Note: Any type of stream (WebDataStream,
            IosAppDataStream, AndroidAppDataStream) may be a
            parent.
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateMeasurementProtocolSecretRequest(proto.Message):
    r"""Request message for UpdateMeasurementProtocolSecret RPC
    Attributes:
        measurement_protocol_secret (google.analytics.admin_v1alpha.types.MeasurementProtocolSecret):
            Required. The measurement protocol secret to
            update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to be updated. Omitted
            fields will not be updated.
    """

    measurement_protocol_secret = proto.Field(
        proto.MESSAGE, number=1, message=resources.MeasurementProtocolSecret,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class ListMeasurementProtocolSecretsRequest(proto.Message):
    r"""Request message for ListMeasurementProtocolSecret RPC
    Attributes:
        parent (str):
            Required. The resource name of the parent
            stream. Any type of stream (WebDataStream,
            IosAppDataStream, AndroidAppDataStream) may be a
            parent.
            Format:
            properties/{property}/webDataStreams/{webDataStream}/measurementProtocolSecrets
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 10 resources will be
            returned. The maximum value is 10. Higher values
            will be coerced to the maximum.
        page_token (str):
            A page token, received from a previous
            ``ListMeasurementProtocolSecrets`` call. Provide this to
            retrieve the subsequent page. When paginating, all other
            parameters provided to ``ListMeasurementProtocolSecrets``
            must match the call that provided the page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListMeasurementProtocolSecretsResponse(proto.Message):
    r"""Response message for ListMeasurementProtocolSecret RPC
    Attributes:
        measurement_protocol_secrets (Sequence[google.analytics.admin_v1alpha.types.MeasurementProtocolSecret]):
            A list of secrets for the parent stream
            specified in the request.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    measurement_protocol_secrets = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.MeasurementProtocolSecret,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetGoogleSignalsSettingsRequest(proto.Message):
    r"""Request message for GetGoogleSignalsSettings RPC
    Attributes:
        name (str):
            Required. The name of the google signals
            settings to retrieve. Format:
            properties/{property}/googleSignalsSettings
    """

    name = proto.Field(proto.STRING, number=1,)


class UpdateGoogleSignalsSettingsRequest(proto.Message):
    r"""Request message for UpdateGoogleSignalsSettings RPC
    Attributes:
        google_signals_settings (google.analytics.admin_v1alpha.types.GoogleSignalsSettings):
            Required. The settings to update. The ``name`` field is used
            to identify the settings to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Field names must
            be in snake case (e.g., "field_to_update"). Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    google_signals_settings = proto.Field(
        proto.MESSAGE, number=1, message=resources.GoogleSignalsSettings,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class CreateConversionEventRequest(proto.Message):
    r"""Request message for CreateConversionEvent RPC
    Attributes:
        conversion_event (google.analytics.admin_v1alpha.types.ConversionEvent):
            Required. The conversion event to create.
        parent (str):
            Required. The resource name of the parent
            property where this conversion event will be
            created. Format: properties/123
    """

    conversion_event = proto.Field(
        proto.MESSAGE, number=1, message=resources.ConversionEvent,
    )
    parent = proto.Field(proto.STRING, number=2,)


class GetConversionEventRequest(proto.Message):
    r"""Request message for GetConversionEvent RPC
    Attributes:
        name (str):
            Required. The resource name of the conversion event to
            retrieve. Format:
            properties/{property}/conversionEvents/{conversion_event}
            Example: "properties/123/conversionEvents/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteConversionEventRequest(proto.Message):
    r"""Request message for DeleteConversionEvent RPC
    Attributes:
        name (str):
            Required. The resource name of the conversion event to
            delete. Format:
            properties/{property}/conversionEvents/{conversion_event}
            Example: "properties/123/conversionEvents/456".
    """

    name = proto.Field(proto.STRING, number=1,)


class ListConversionEventsRequest(proto.Message):
    r"""Request message for ListConversionEvents RPC
    Attributes:
        parent (str):
            Required. The resource name of the parent
            property. Example: 'properties/123'
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200; (higher
            values will be coerced to the maximum)
        page_token (str):
            A page token, received from a previous
            ``ListConversionEvents`` call. Provide this to retrieve the
            subsequent page. When paginating, all other parameters
            provided to ``ListConversionEvents`` must match the call
            that provided the page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListConversionEventsResponse(proto.Message):
    r"""Response message for ListConversionEvents RPC.
    Attributes:
        conversion_events (Sequence[google.analytics.admin_v1alpha.types.ConversionEvent]):
            The requested conversion events
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    conversion_events = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.ConversionEvent,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class CreateCustomDimensionRequest(proto.Message):
    r"""Request message for CreateCustomDimension RPC.
    Attributes:
        parent (str):
            Required. Example format: properties/1234
        custom_dimension (google.analytics.admin_v1alpha.types.CustomDimension):
            Required. The CustomDimension to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    custom_dimension = proto.Field(
        proto.MESSAGE, number=2, message=resources.CustomDimension,
    )


class UpdateCustomDimensionRequest(proto.Message):
    r"""Request message for UpdateCustomDimension RPC.
    Attributes:
        custom_dimension (google.analytics.admin_v1alpha.types.CustomDimension):
            The CustomDimension to update
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    custom_dimension = proto.Field(
        proto.MESSAGE, number=1, message=resources.CustomDimension,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class ListCustomDimensionsRequest(proto.Message):
    r"""Request message for ListCustomDimensions RPC.
    Attributes:
        parent (str):
            Required. Example format: properties/1234
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200 (higher
            values will be coerced to the maximum).
        page_token (str):
            A page token, received from a previous
            ``ListCustomDimensions`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListCustomDimensions`` must match the call that provided
            the page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListCustomDimensionsResponse(proto.Message):
    r"""Response message for ListCustomDimensions RPC.
    Attributes:
        custom_dimensions (Sequence[google.analytics.admin_v1alpha.types.CustomDimension]):
            List of CustomDimensions.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    custom_dimensions = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.CustomDimension,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class ArchiveCustomDimensionRequest(proto.Message):
    r"""Request message for ArchiveCustomDimension RPC.
    Attributes:
        name (str):
            Required. The name of the CustomDimension to
            archive. Example format:
            properties/1234/customDimensions/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class GetCustomDimensionRequest(proto.Message):
    r"""Request message for GetCustomDimension RPC.
    Attributes:
        name (str):
            Required. The name of the CustomDimension to
            get. Example format:
            properties/1234/customDimensions/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateCustomMetricRequest(proto.Message):
    r"""Request message for CreateCustomMetric RPC.
    Attributes:
        parent (str):
            Required. Example format: properties/1234
        custom_metric (google.analytics.admin_v1alpha.types.CustomMetric):
            Required. The CustomMetric to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    custom_metric = proto.Field(
        proto.MESSAGE, number=2, message=resources.CustomMetric,
    )


class UpdateCustomMetricRequest(proto.Message):
    r"""Request message for UpdateCustomMetric RPC.
    Attributes:
        custom_metric (google.analytics.admin_v1alpha.types.CustomMetric):
            The CustomMetric to update
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to be updated. Omitted fields
            will not be updated. To replace the entire entity, use one
            path with the string "*" to match all fields.
    """

    custom_metric = proto.Field(
        proto.MESSAGE, number=1, message=resources.CustomMetric,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class ListCustomMetricsRequest(proto.Message):
    r"""Request message for ListCustomMetrics RPC.
    Attributes:
        parent (str):
            Required. Example format: properties/1234
        page_size (int):
            The maximum number of resources to return.
            If unspecified, at most 50 resources will be
            returned. The maximum value is 200 (higher
            values will be coerced to the maximum).
        page_token (str):
            A page token, received from a previous ``ListCustomMetrics``
            call. Provide this to retrieve the subsequent page.

            When paginating, all other parameters provided to
            ``ListCustomMetrics`` must match the call that provided the
            page token.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListCustomMetricsResponse(proto.Message):
    r"""Response message for ListCustomMetrics RPC.
    Attributes:
        custom_metrics (Sequence[google.analytics.admin_v1alpha.types.CustomMetric]):
            List of CustomMetrics.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    custom_metrics = proto.RepeatedField(
        proto.MESSAGE, number=1, message=resources.CustomMetric,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class ArchiveCustomMetricRequest(proto.Message):
    r"""Request message for ArchiveCustomMetric RPC.
    Attributes:
        name (str):
            Required. The name of the CustomMetric to
            archive. Example format:
            properties/1234/customMetrics/5678
    """

    name = proto.Field(proto.STRING, number=1,)


class GetCustomMetricRequest(proto.Message):
    r"""Request message for GetCustomMetric RPC.
    Attributes:
        name (str):
            Required. The name of the CustomMetric to
            get. Example format:
            properties/1234/customMetrics/5678
    """

    name = proto.Field(proto.STRING, number=1,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore
from google.protobuf import wrappers_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.analytics.admin.v1alpha",
    manifest={
        "MaximumUserAccess",
        "IndustryCategory",
        "ActorType",
        "ActionType",
        "ChangeHistoryResourceType",
        "GoogleSignalsState",
        "GoogleSignalsConsent",
        "Account",
        "Property",
        "AndroidAppDataStream",
        "IosAppDataStream",
        "WebDataStream",
        "UserLink",
        "AuditUserLink",
        "EnhancedMeasurementSettings",
        "FirebaseLink",
        "GlobalSiteTag",
        "GoogleAdsLink",
        "DataSharingSettings",
        "AccountSummary",
        "PropertySummary",
        "MeasurementProtocolSecret",
        "ChangeHistoryEvent",
        "ChangeHistoryChange",
        "ConversionEvent",
        "GoogleSignalsSettings",
        "CustomDimension",
        "CustomMetric",
    },
)


class MaximumUserAccess(proto.Enum):
    r"""Maximum access settings that Firebase user receive on the
    linked Analytics property.
    """
    MAXIMUM_USER_ACCESS_UNSPECIFIED = 0
    NO_ACCESS = 1
    READ_AND_ANALYZE = 2
    EDITOR_WITHOUT_LINK_MANAGEMENT = 3
    EDITOR_INCLUDING_LINK_MANAGEMENT = 4


class IndustryCategory(proto.Enum):
    r"""The category selected for this property, used for industry
    benchmarking.
    """
    INDUSTRY_CATEGORY_UNSPECIFIED = 0
    AUTOMOTIVE = 1
    BUSINESS_AND_INDUSTRIAL_MARKETS = 2
    FINANCE = 3
    HEALTHCARE = 4
    TECHNOLOGY = 5
    TRAVEL = 6
    OTHER = 7
    ARTS_AND_ENTERTAINMENT = 8
    BEAUTY_AND_FITNESS = 9
    BOOKS_AND_LITERATURE = 10
    FOOD_AND_DRINK = 11
    GAMES = 12
    HOBBIES_AND_LEISURE = 13
    HOME_AND_GARDEN = 14
    INTERNET_AND_TELECOM = 15
    LAW_AND_GOVERNMENT = 16
    NEWS = 17
    ONLINE_COMMUNITIES = 18
    PEOPLE_AND_SOCIETY = 19
    PETS_AND_ANIMALS = 20
    REAL_ESTATE = 21
    REFERENCE = 22
    SCIENCE = 23
    SPORTS = 24
    JOBS_AND_EDUCATION = 25
    SHOPPING = 26


class ActorType(proto.Enum):
    r"""Different kinds of actors that can make changes to Google
    Analytics resources.
    """
    ACTOR_TYPE_UNSPECIFIED = 0
    USER = 1
    SYSTEM = 2
    SUPPORT = 3


class ActionType(proto.Enum):
    r"""Types of actions that may change a resource."""
    ACTION_TYPE_UNSPECIFIED = 0
    CREATED = 1
    UPDATED = 2
    DELETED = 3


class ChangeHistoryResourceType(proto.Enum):
    r"""Types of resources whose changes may be returned from change
    history.
    """
    CHANGE_HISTORY_RESOURCE_TYPE_UNSPECIFIED = 0
    ACCOUNT = 1
    PROPERTY = 2
    WEB_DATA_STREAM = 3
    ANDROID_APP_DATA_STREAM = 4
    IOS_APP_DATA_STREAM = 5
    FIREBASE_LINK = 6
    GOOGLE_ADS_LINK = 7
    GOOGLE_SIGNALS_SETTINGS = 8
    CONVERSION_EVENT = 9
    MEASUREMENT_PROTOCOL_SECRET = 10
    CUSTOM_DIMENSION = 11
    CUSTOM_METRIC = 12


class GoogleSignalsState(proto.Enum):
    r"""Status of the Google Signals settings (i.e., whether this
    feature has been enabled for the property).
    """
    GOOGLE_SIGNALS_STATE_UNSPECIFIED = 0
    GOOGLE_SIGNALS_ENABLED = 1
    GOOGLE_SIGNALS_DISABLED = 2


class GoogleSignalsConsent(proto.Enum):
    r"""Consent field of the Google Signals settings (i.e., whether
    the user has consented to the Google Signals terms of service.)
    """
    GOOGLE_SIGNALS_CONSENT_UNSPECIFIED = 0
    GOOGLE_SIGNALS_CONSENT_CONSENTED = 2
    GOOGLE_SIGNALS_CONSENT_NOT_CONSENTED = 1


class Account(proto.Message):
    r"""A resource message representing a Google Analytics account.
    Attributes:
        name (str):
            Output only. Resource name of this account.
            Format: accounts/{account}
            Example: "accounts/100".
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this account was
            originally created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when account payload fields
            were last updated.
        display_name (str):
            Required. Human-readable display name for
            this account.
        region_code (str):
            Country of business. Must be a Unicode CLDR
            region code.
        deleted (bool):
            Output only. Indicates whether this Account
            is soft-deleted or not. Deleted accounts are
            excluded from List results unless specifically
            requested.
    """

    name = proto.Field(proto.STRING, number=1,)
    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    display_name = proto.Field(proto.STRING, number=4,)
    region_code = proto.Field(proto.STRING, number=5,)
    deleted = proto.Field(proto.BOOL, number=6,)


class Property(proto.Message):
    r"""A resource message representing a Google Analytics GA4
    property.

    Attributes:
        name (str):
            Output only. Resource name of this property. Format:
            properties/{property_id} Example: "properties/1000".
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when the entity was
            originally created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when entity payload fields
            were last updated.
        parent (str):
            Immutable. Resource name of this property's
            logical parent.
            Note: The Property-Moving UI can be used to
            change the parent. Format: accounts/{account}
            Example: "accounts/100".
        display_name (str):
            Required. Human-readable display name for
            this property.
            The max allowed display name length is 100
            UTF-16 code units.
        industry_category (google.analytics.admin_v1alpha.types.IndustryCategory):
            Industry associated with this property Example: AUTOMOTIVE,
            FOOD_AND_DRINK
        time_zone (str):
            Required. Reporting Time Zone, used as the day boundary for
            reports, regardless of where the data originates. If the
            time zone honors DST, Analytics will automatically adjust
            for the changes.

            NOTE: Changing the time zone only affects data going
            forward, and is not applied retroactively.

            Format: https://www.iana.org/time-zones Example:
            "America/Los_Angeles".
        currency_code (str):
            The currency type used in reports involving monetary values.

            Format: https://en.wikipedia.org/wiki/ISO_4217 Examples:
            "USD", "EUR", "JPY".
        delete_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. If set, the time at which this
            property was trashed. If not set, then this
            property is not currently in the trash can.
        expire_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. If set, the time at which this
            trashed property will be permanently deleted. If
            not set, then this property is not currently in
            the trash can and is not slated to be deleted.
    """

    name = proto.Field(proto.STRING, number=1,)
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    parent = proto.Field(proto.STRING, number=2,)
    display_name = proto.Field(proto.STRING, number=5,)
    industry_category = proto.Field(proto.ENUM, number=6, enum="IndustryCategory",)
    time_zone = proto.Field(proto.STRING, number=7,)
    currency_code = proto.Field(proto.STRING, number=8,)
    delete_time = proto.Field(
        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
    )
    expire_time = proto.Field(
        proto.MESSAGE, number=12, message=timestamp_pb2.Timestamp,
    )


class AndroidAppDataStream(proto.Message):
    r"""A resource message representing a Google Analytics Android
    app stream.

    Attributes:
        name (str):
            Output only. Resource name of this Data Stream. Format:
            properties/{property_id}/androidAppDataStreams/{stream_id}
            Example: "properties/1000/androidAppDataStreams/2000".
        firebase_app_id (str):
            Output only. ID of the corresponding Android
            app in Firebase, if any. This ID can change if
            the Android app is deleted and recreated.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this stream was
            originally created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when stream payload fields
            were last updated.
        package_name (str):
            Immutable. The package name for the app being
            measured. Example: "com.example.myandroidapp".
        display_name (str):
            Human-readable display name for the Data
            Stream.
            The max allowed display name length is 255
            UTF-16 code units.
    """

    name = proto.Field(proto.STRING, number=1,)
    firebase_app_id = proto.Field(proto.STRING, number=2,)
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    package_name = proto.Field(proto.STRING, number=5,)
    display_name = proto.Field(proto.STRING, number=6,)


class IosAppDataStream(proto.Message):
    r"""A resource message representing a Google Analytics IOS app
    stream.

    Attributes:
        name (str):
            Output only. Resource name of this Data Stream. Format:
            properties/{property_id}/iosAppDataStreams/{stream_id}
            Example: "properties/1000/iosAppDataStreams/2000".
        firebase_app_id (str):
            Output only. ID of the corresponding iOS app
            in Firebase, if any. This ID can change if the
            iOS app is deleted and recreated.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this stream was
            originally created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when stream payload fields
            were last updated.
        bundle_id (str):
            Required. Immutable. The Apple App Store
            Bundle ID for the app Example:
            "com.example.myiosapp".
        display_name (str):
            Human-readable display name for the Data
            Stream.
            The max allowed display name length is 255
            UTF-16 code units.
    """

    name = proto.Field(proto.STRING, number=1,)
    firebase_app_id = proto.Field(proto.STRING, number=2,)
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    bundle_id = proto.Field(proto.STRING, number=5,)
    display_name = proto.Field(proto.STRING, number=6,)


class WebDataStream(proto.Message):
    r"""A resource message representing a Google Analytics web
    stream.

    Attributes:
        name (str):
            Output only. Resource name of this Data Stream. Format:
            properties/{property_id}/webDataStreams/{stream_id} Example:
            "properties/1000/webDataStreams/2000".
        measurement_id (str):
            Output only. Analytics "Measurement ID",
            without the "G-" prefix. Example: "G-1A2BCD345E"
            would just be "1A2BCD345E".
        firebase_app_id (str):
            Output only. ID of the corresponding web app
            in Firebase, if any. This ID can change if the
            web app is deleted and recreated.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this stream was
            originally created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when stream payload fields
            were last updated.
        default_uri (str):
            Immutable. Domain name of the web app being
            measured, or empty. Example:
            "http://www.google.com",
            "https://www.google.com".
        display_name (str):
            Required. Human-readable display name for the
            Data Stream.
            The max allowed display name length is 100
            UTF-16 code units.
    """

    name = proto.Field(proto.STRING, number=1,)
    measurement_id = proto.Field(proto.STRING, number=2,)
    firebase_app_id = proto.Field(proto.STRING, number=3,)
    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
    default_uri = proto.Field(proto.STRING, number=6,)
    display_name = proto.Field(proto.STRING, number=7,)


class UserLink(proto.Message):
    r"""A resource message representing a user's permissions on an
    Account or Property resource.

    Attributes:
        name (str):
            Output only. Example format:
            properties/1234/userLinks/5678
        email_address (str):
            Immutable. Email address of the user to link
        direct_roles (Sequence[str]):
            Roles directly assigned to this user for this account or
            property.

            Valid values: predefinedRoles/read
            predefinedRoles/collaborate predefinedRoles/edit
            predefinedRoles/manage-users

            Excludes roles that are inherited from a higher-level
            entity, group, or organization admin role.

            A UserLink that is updated to have an empty list of
            direct_roles will be deleted.
    """

    name = proto.Field(proto.STRING, number=1,)
    email_address = proto.Field(proto.STRING, number=2,)
    direct_roles = proto.RepeatedField(proto.STRING, number=3,)


class AuditUserLink(proto.Message):
    r"""Read-only resource used to summarize a principal's effective
    roles.

    Attributes:
        name (str):
            Example format:
            properties/1234/userLinks/5678
        email_address (str):
            Email address of the linked user
        direct_roles (Sequence[str]):
            Roles directly assigned to this user for this
            entity.
            Format: predefinedRoles/read

            Excludes roles that are inherited from an
            account (if this is for a property), group, or
            organization admin role.
        effective_roles (Sequence[str]):
            Union of all permissions a user has at this
            account or property (includes direct
            permissions, group-inherited permissions, etc.).
            Format: predefinedRoles/read
    """

    name = proto.Field(proto.STRING, number=1,)
    email_address = proto.Field(proto.STRING, number=2,)
    direct_roles = proto.RepeatedField(proto.STRING, number=3,)
    effective_roles = proto.RepeatedField(proto.STRING, number=4,)


class EnhancedMeasurementSettings(proto.Message):
    r"""Singleton resource under a WebDataStream, configuring
    measurement of additional site interactions and content.

    Attributes:
        name (str):
            Output only. Resource name of this Data Stream. Format:
            properties/{property_id}/webDataStreams/{stream_id}/enhancedMeasurementSettings
            Example:
            "properties/1000/webDataStreams/2000/enhancedMeasurementSettings".
        stream_enabled (bool):
            Indicates whether Enhanced Measurement
            Settings will be used to automatically measure
            interactions and content on this web stream.
            Changing this value does not affect the settings
            themselves, but determines whether they are
            respected.
        page_views_enabled (bool):
            Output only. If enabled, capture a page view
            event each time a page loads or the website
            changes the browser history state.
        scrolls_enabled (bool):
            If enabled, capture scroll events each time a
            visitor gets to the bottom of a page.
        outbound_clicks_enabled (bool):
            If enabled, capture an outbound click event
            each time a visitor clicks a link that leads
            them away from your domain.
        site_search_enabled (bool):
            If enabled, capture a view search results
            event each time a visitor performs a search on
            your site (based on a query parameter).
        video_engagement_enabled (bool):
            If enabled, capture video play, progress, and
            complete events as visitors view embedded videos
            on your site.
        file_downloads_enabled (bool):
            If enabled, capture a file download event
            each time a link is clicked with a common
            document, compressed file, application, video,
            or audio extension.
        page_loads_enabled (bool):
            Output only. If enabled, capture a page view
            event each time a page loads.
        page_changes_enabled (bool):
            If enabled, capture a page view event each
            time the website changes the browser history
            state.
        search_query_parameter (str):
            Required. URL query parameters to interpret
            as site search parameters. Max length is 1024
            characters. Must not be empty.
        uri_query_parameter (str):
            Additional URL query parameters.
            Max length is 1024 characters.
    """

    name = proto.Field(proto.STRING, number=1,)
    stream_enabled = proto.Field(proto.BOOL, number=2,)
    page_views_enabled = proto.Field(proto.BOOL, number=3,)
    scrolls_enabled = proto.Field(proto.BOOL, number=4,)
    outbound_clicks_enabled = proto.Field(proto.BOOL, number=5,)
    site_search_enabled = proto.Field(proto.BOOL, number=7,)
    video_engagement_enabled = proto.Field(proto.BOOL, number=9,)
    file_downloads_enabled = proto.Field(proto.BOOL, number=10,)
    page_loads_enabled = proto.Field(proto.BOOL, number=12,)
    page_changes_enabled = proto.Field(proto.BOOL, number=13,)
    search_query_parameter = proto.Field(proto.STRING, number=16,)
    uri_query_parameter = proto.Field(proto.STRING, number=17,)


class FirebaseLink(proto.Message):
    r"""A link between an GA4 property and a Firebase project.
    Attributes:
        name (str):
            Output only. Example format:
            properties/1234/firebaseLinks/5678
        project (str):
            Immutable. Firebase project resource name. When creating a
            FirebaseLink, you may provide this resource name using
            either a project number or project ID. Once this resource
            has been created, returned FirebaseLinks will always have a
            project_name that contains a project number.

            Format: 'projects/{project number}' Example: 'projects/1234'
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this FirebaseLink was
            originally created.
        maximum_user_access (google.analytics.admin_v1alpha.types.MaximumUserAccess):
            Maximum user access to the GA4 property
            allowed to admins of the linked Firebase
            project.
    """

    name = proto.Field(proto.STRING, number=1,)
    project = proto.Field(proto.STRING, number=2,)
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    maximum_user_access = proto.Field(proto.ENUM, number=4, enum="MaximumUserAccess",)


class GlobalSiteTag(proto.Message):
    r"""Read-only resource with the tag for sending data from a
    website to a WebDataStream.

    Attributes:
        name (str):
            Output only. Resource name for this
            GlobalSiteTag resource. Format:
            properties/{propertyId}/globalSiteTag
        snippet (str):
            Immutable. JavaScript code snippet to be
            pasted as the first item into the head tag of
            every webpage to measure.
    """

    name = proto.Field(proto.STRING, number=1,)
    snippet = proto.Field(proto.STRING, number=2,)


class GoogleAdsLink(proto.Message):
    r"""A link between an GA4 property and a Google Ads account.
    Attributes:
        name (str):
            Output only. Format:
            properties/{propertyId}/googleAdsLinks/{googleAdsLinkId}
            Note: googleAdsLinkId is not the Google Ads
            customer ID.
        customer_id (str):
            Immutable. Google Ads customer ID.
        can_manage_clients (bool):
            Output only. If true, this link is for a
            Google Ads manager account.
        ads_personalization_enabled (google.protobuf.wrappers_pb2.BoolValue):
            Enable personalized advertising features with
            this integration. Automatically publish my
            Google Analytics audience lists and Google
            Analytics remarketing events/parameters to the
            linked Google Ads account. If this field is not
            set on create/update, it will be defaulted to
            true.
        email_address (str):
            Output only. Email address of the user that
            created the link. An empty string will be
            returned if the email address can't be
            retrieved.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this link was
            originally created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this link was last
            updated.
    """

    name = proto.Field(proto.STRING, number=1,)
    customer_id = proto.Field(proto.STRING, number=3,)
    can_manage_clients = proto.Field(proto.BOOL, number=4,)
    ads_personalization_enabled = proto.Field(
        proto.MESSAGE, number=5, message=wrappers_pb2.BoolValue,
    )
    email_address = proto.Field(proto.STRING, number=6,)
    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
    update_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)


class DataSharingSettings(proto.Message):
    r"""A resource message representing data sharing settings of a
    Google Analytics account.

    Attributes:
        name (str):
            Output only. Resource name.
            Format: accounts/{account}/dataSharingSettings
            Example: "accounts/1000/dataSharingSettings".
        sharing_with_google_support_enabled (bool):
            Allows Google support to access the data in
            order to help troubleshoot issues.
        sharing_with_google_assigned_sales_enabled (bool):
            Allows Google sales teams that are assigned
            to the customer to access the data in order to
            suggest configuration changes to improve
            results. Sales team restrictions still apply
            when enabled.
        sharing_with_google_any_sales_enabled (bool):
            Allows any of Google sales to access the data
            in order to suggest configuration changes to
            improve results.
        sharing_with_google_products_enabled (bool):
            Allows Google to use the data to improve
            other Google products or services.
        sharing_with_others_enabled (bool):
            Allows Google to share the data anonymously
            in aggregate form with others.
    """

    name = proto.Field(proto.STRING, number=1,)
    sharing_with_google_support_enabled = proto.Field(proto.BOOL, number=2,)
    sharing_with_google_assigned_sales_enabled = proto.Field(proto.BOOL, number=3,)
    sharing_with_google_any_sales_enabled = proto.Field(proto.BOOL, number=4,)
    sharing_with_google_products_enabled = proto.Field(proto.BOOL, number=5,)
    sharing_with_others_enabled = proto.Field(proto.BOOL, number=6,)


class AccountSummary(proto.Message):
    r"""A virtual resource representing an overview of an account and
    all its child GA4 properties.

    Attributes:
        name (str):
            Resource name for this account summary. Format:
            accountSummaries/{account_id} Example:
            "accountSummaries/1000".
        account (str):
            Resource name of account referred to by this account summary
            Format: accounts/{account_id} Example: "accounts/1000".
        display_name (str):
            Display name for the account referred to in
            this account summary.
        property_summaries (Sequence[google.analytics.admin_v1alpha.types.PropertySummary]):
            List of summaries for child accounts of this
            account.
    """

    name = proto.Field(proto.STRING, number=1,)
    account = proto.Field(proto.STRING, number=2,)
    display_name = proto.Field(proto.STRING, number=3,)
    property_summaries = proto.RepeatedField(
        proto.MESSAGE, number=4, message="PropertySummary",
    )


class PropertySummary(proto.Message):
    r"""A virtual resource representing metadata for an GA4 property.
    Attributes:
        property (str):
            Resource name of property referred to by this property
            summary Format: properties/{property_id} Example:
            "properties/1000".
        display_name (str):
            Display name for the property referred to in
            this account summary.
    """

    property = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)


class MeasurementProtocolSecret(proto.Message):
    r"""A secret value used for sending hits to Measurement Protocol.
    Attributes:
        name (str):
            Output only. Resource name of this secret.
            This secret may be a child of any type of
            stream. Format:
            properties/{property}/webDataStreams/{webDataStream}/measurementProtocolSecrets/{measurementProtocolSecret}
        display_name (str):
            Required. Human-readable display name for
            this secret.
        secret_value (str):
            Output only. The measurement protocol secret value. Pass
            this value to the api_secret field of the Measurement
            Protocol API when sending hits to this secret's parent
            property.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    secret_value = proto.Field(proto.STRING, number=3,)


class ChangeHistoryEvent(proto.Message):
    r"""A set of changes within a Google Analytics account or its
    child properties that resulted from the same cause. Common
    causes would be updates made in the Google Analytics UI, changes
    from customer support, or automatic Google Analytics system
    changes.

    Attributes:
        id (str):
            ID of this change history event. This ID is
            unique across Google Analytics.
        change_time (google.protobuf.timestamp_pb2.Timestamp):
            Time when change was made.
        actor_type (google.analytics.admin_v1alpha.types.ActorType):
            The type of actor that made this change.
        user_actor_email (str):
            Email address of the Google account that made
            the change. This will be a valid email address
            if the actor field is set to USER, and empty
            otherwise. Google accounts that have been
            deleted will cause an error.
        changes_filtered (bool):
            If true, then the list of changes returned
            was filtered, and does not represent all changes
            that occurred in this event.
        changes (Sequence[google.analytics.admin_v1alpha.types.ChangeHistoryChange]):
            A list of changes made in this change history
            event that fit the filters specified in
            SearchChangeHistoryEventsRequest.
    """

    id = proto.Field(proto.STRING, number=1,)
    change_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
    actor_type = proto.Field(proto.ENUM, number=3, enum="ActorType",)
    user_actor_email = proto.Field(proto.STRING, number=4,)
    changes_filtered = proto.Field(proto.BOOL, number=5,)
    changes = proto.RepeatedField(
        proto.MESSAGE, number=6, message="ChangeHistoryChange",
    )


class ChangeHistoryChange(proto.Message):
    r"""A description of a change to a single Google Analytics
    resource.

    Attributes:
        resource (str):
            Resource name of the resource whose changes
            are described by this entry.
        action (google.analytics.admin_v1alpha.types.ActionType):
            The type of action that changed this
            resource.
        resource_before_change (google.analytics.admin_v1alpha.types.ChangeHistoryChange.ChangeHistoryResource):
            Resource contents from before the change was
            made. If this resource was created in this
            change, this field will be missing.
        resource_after_change (google.analytics.admin_v1alpha.types.ChangeHistoryChange.ChangeHistoryResource):
            Resource contents from after the change was
            made. If this resource was deleted in this
            change, this field will be missing.
    """

    class ChangeHistoryResource(proto.Message):
        r"""A snapshot of a resource as before or after the result of a
        change in change history.

        Attributes:
            account (google.analytics.admin_v1alpha.types.Account):
                A snapshot of an Account resource in change
                history.
            property (google.analytics.admin_v1alpha.types.Property):
                A snapshot of a Property resource in change
                history.
            web_data_stream (google.analytics.admin_v1alpha.types.WebDataStream):
                A snapshot of a WebDataStream resource in
                change history.
            android_app_data_stream (google.analytics.admin_v1alpha.types.AndroidAppDataStream):
                A snapshot of an AndroidAppDataStream
                resource in change history.
            ios_app_data_stream (google.analytics.admin_v1alpha.types.IosAppDataStream):
                A snapshot of an IosAppDataStream resource in
                change history.
            firebase_link (google.analytics.admin_v1alpha.types.FirebaseLink):
                A snapshot of a FirebaseLink resource in
                change history.
            google_ads_link (google.analytics.admin_v1alpha.types.GoogleAdsLink):
                A snapshot of a GoogleAdsLink resource in
                change history.
            google_signals_settings (google.analytics.admin_v1alpha.types.GoogleSignalsSettings):
                A snapshot of a GoogleSignalsSettings
                resource in change history.
            conversion_event (google.analytics.admin_v1alpha.types.ConversionEvent):
                A snapshot of a ConversionEvent resource in
                change history.
            measurement_protocol_secret (google.analytics.admin_v1alpha.types.MeasurementProtocolSecret):
                A snapshot of a MeasurementProtocolSecret
                resource in change history.
            custom_dimension (google.analytics.admin_v1alpha.types.CustomDimension):
                A snapshot of a CustomDimension resource in
                change history.
            custom_metric (google.analytics.admin_v1alpha.types.CustomMetric):
                A snapshot of a CustomMetric resource in
                change history.
        """

        account = proto.Field(
            proto.MESSAGE, number=1, oneof="resource", message="Account",
        )
        property = proto.Field(
            proto.MESSAGE, number=2, oneof="resource", message="Property",
        )
        web_data_stream = proto.Field(
            proto.MESSAGE, number=3, oneof="resource", message="WebDataStream",
        )
        android_app_data_stream = proto.Field(
            proto.MESSAGE, number=4, oneof="resource", message="AndroidAppDataStream",
        )
        ios_app_data_stream = proto.Field(
            proto.MESSAGE, number=5, oneof="resource", message="IosAppDataStream",
        )
        firebase_link = proto.Field(
            proto.MESSAGE, number=6, oneof="resource", message="FirebaseLink",
        )
        google_ads_link = proto.Field(
            proto.MESSAGE, number=7, oneof="resource", message="GoogleAdsLink",
        )
        google_signals_settings = proto.Field(
            proto.MESSAGE, number=8, oneof="resource", message="GoogleSignalsSettings",
        )
        conversion_event = proto.Field(
            proto.MESSAGE, number=11, oneof="resource", message="ConversionEvent",
        )
        measurement_protocol_secret = proto.Field(
            proto.MESSAGE,
            number=12,
            oneof="resource",
            message="MeasurementProtocolSecret",
        )
        custom_dimension = proto.Field(
            proto.MESSAGE, number=13, oneof="resource", message="CustomDimension",
        )
        custom_metric = proto.Field(
            proto.MESSAGE, number=14, oneof="resource", message="CustomMetric",
        )

    resource = proto.Field(proto.STRING, number=1,)
    action = proto.Field(proto.ENUM, number=2, enum="ActionType",)
    resource_before_change = proto.Field(
        proto.MESSAGE, number=3, message=ChangeHistoryResource,
    )
    resource_after_change = proto.Field(
        proto.MESSAGE, number=4, message=ChangeHistoryResource,
    )


class ConversionEvent(proto.Message):
    r"""A conversion event in a Google Analytics property.
    Attributes:
        name (str):
            Output only. Resource name of this conversion event. Format:
            properties/{property}/conversionEvents/{conversion_event}
        event_name (str):
            Immutable. The event name for this conversion
            event. Examples: 'click', 'purchase'
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when this conversion event
            was created in the property.
        is_deletable (bool):
            Output only. If set, this event can currently
            be deleted via DeleteConversionEvent.
    """

    name = proto.Field(proto.STRING, number=1,)
    event_name = proto.Field(proto.STRING, number=2,)
    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
    is_deletable = proto.Field(proto.BOOL, number=4,)


class GoogleSignalsSettings(proto.Message):
    r"""Settings values for Google Signals.  This is a singleton
    resource.

    Attributes:
        name (str):
            Output only. Resource name of this setting. Format:
            properties/{property_id}/googleSignalsSettings Example:
            "properties/1000/googleSignalsSettings".
        state (google.analytics.admin_v1alpha.types.GoogleSignalsState):
            Status of this setting.
        consent (google.analytics.admin_v1alpha.types.GoogleSignalsConsent):
            Output only. Terms of Service acceptance.
    """

    name = proto.Field(proto.STRING, number=1,)
    state = proto.Field(proto.ENUM, number=3, enum="GoogleSignalsState",)
    consent = proto.Field(proto.ENUM, number=4, enum="GoogleSignalsConsent",)


class CustomDimension(proto.Message):
    r"""A definition for a CustomDimension.
    Attributes:
        name (str):
            Output only. Resource name for this
            CustomDimension resource. Format:
            properties/{property}/customDimensions/{customDimension}
        parameter_name (str):
            Required. Immutable. Tagging parameter name
            for this custom dimension.
            If this is a user-scoped dimension, then this is
            the user property name. If this is an event-
            scoped dimension, then this is the event
            parameter name.

            May only contain alphanumeric and underscore
            characters, starting with a letter. Max length
            of 24 characters for user-scoped dimensions, 40
            characters for event-scoped dimensions.
        display_name (str):
            Required. Display name for this custom
            dimension as shown in the Analytics UI. Max
            length of 82 characters, alphanumeric plus space
            and underscore starting with a letter. Legacy
            system-generated display names may contain
            square brackets, but updates to this field will
            never permit square brackets.
        description (str):
            Optional. Description for this custom
            dimension. Max length of 150 characters.
        scope (google.analytics.admin_v1alpha.types.CustomDimension.DimensionScope):
            Required. Immutable. The scope of this
            dimension.
        disallow_ads_personalization (bool):
            Optional. If set to true, sets this dimension
            as NPA and excludes it from ads personalization.
            This is currently only supported by user-scoped
            custom dimensions.
    """

    class DimensionScope(proto.Enum):
        r"""Valid values for the scope of this dimension."""
        DIMENSION_SCOPE_UNSPECIFIED = 0
        EVENT = 1
        USER = 2

    name = proto.Field(proto.STRING, number=1,)
    parameter_name = proto.Field(proto.STRING, number=2,)
    display_name = proto.Field(proto.STRING, number=3,)
    description = proto.Field(proto.STRING, number=4,)
    scope = proto.Field(proto.ENUM, number=5, enum=DimensionScope,)
    disallow_ads_personalization = proto.Field(proto.BOOL, number=6,)


class CustomMetric(proto.Message):
    r"""A definition for a custom metric.
    Attributes:
        name (str):
            Output only. Resource name for this
            CustomMetric resource. Format:
            properties/{property}/customMetrics/{customMetric}
        parameter_name (str):
            Required. Immutable. Tagging name for this
            custom metric.
            If this is an event-scoped metric, then this is
            the event parameter name.

            May only contain alphanumeric and underscore
            charactes, starting with a letter. Max length of
            40 characters for event-scoped metrics.
        display_name (str):
            Required. Display name for this custom metric
            as shown in the Analytics UI. Max length of 82
            characters, alphanumeric plus space and
            underscore starting with a letter. Legacy
            system-generated display names may contain
            square brackets, but updates to this field will
            never permit square brackets.
        description (str):
            Optional. Description for this custom
            dimension. Max length of 150 characters.
        measurement_unit (google.analytics.admin_v1alpha.types.CustomMetric.MeasurementUnit):
            Required. Immutable. The type for the custom
            metric's value.
        scope (google.analytics.admin_v1alpha.types.CustomMetric.MetricScope):
            Required. Immutable. The scope of this custom
            metric.
    """

    class MeasurementUnit(proto.Enum):
        r"""Possible types of representing the custom metric's value.
        Currency representation may change in the future, requiring a
        breaking API change.
        """
        MEASUREMENT_UNIT_UNSPECIFIED = 0
        STANDARD = 1
        CURRENCY = 2
        FEET = 3
        METERS = 4
        KILOMETERS = 5
        MILES = 6
        MILLISECONDS = 7
        SECONDS = 8
        MINUTES = 9
        HOURS = 10

    class MetricScope(proto.Enum):
        r"""The scope of this metric."""
        METRIC_SCOPE_UNSPECIFIED = 0
        EVENT = 1

    name = proto.Field(proto.STRING, number=1,)
    parameter_name = proto.Field(proto.STRING, number=2,)
    display_name = proto.Field(proto.STRING, number=3,)
    description = proto.Field(proto.STRING, number=4,)
    measurement_unit = proto.Field(proto.ENUM, number=5, enum=MeasurementUnit,)
    scope = proto.Field(proto.ENUM, number=6, enum=MetricScope,)


__all__ = tuple(sorted(__protobuf__.manifest))
